import { useState } from "react";
import { useNavigate } from "react-router-dom";
import { addBebida } from "./bebidas-service";
import Swal from 'sweetalert2'


export default function AddBebida() {

    const [nombre, setNombre] = useState('');
    const [precio, setPrecio] = useState('');
    const [cantidad, setCantidad] = useState('');

    const navigate = useNavigate();

    const handleSubmit = async (e) => {
        e.preventDefault();

        if (!nombre || !precio) {
            Swal.fire({
                icon: 'error',
                title: 'Por favor, completa todos los campos.'
            })
            return;
        }

        let precioNuevo = parseFloat(precio);
        let cantidadNueva = parseInt(cantidad);

        if (isNaN(cantidadNueva) || isNaN(precioNuevo) || precio <= 0 || cantidad < 0) {
            Swal.fire({
                icon: 'error',
                title: 'Cantidad y Precio deben ser números válidos'
            })
            return;
        }

        const bebidaNueva = {nombre: nombre, precio: precioNuevo, cantidad: cantidadNueva}

        try {
            addBebida(bebidaNueva)
            navigate('/deposito');
        } catch (error) {
            Swal.fire({
                icon: 'error',
                title: `Error al agregar bebida: ${error.message}`
            })
        }
    };

    return (
        <div className="container text-center border border-5 rounded-5 table-responsive mt-3">
            <h1 className="mt-4">Agregar Bebida</h1>
            <form onSubmit={handleSubmit}>
                <div className="form-floating mx-5 my-4">         
                    <input
                        type="text"
                        className="form-control"
                        id="nombre"
                        value={nombre}
                        onChange={(e) => setNombre(e.target.value)}
                        required
                    />
                    <label htmlFor="nombre" className="form-label">Nombre del producto:</label>
                </div>
                <div className="form-floating mx-5 my-4">
                    <input
                        type="number"
                        className="form-control"
                        id="precio"
                        value={precio}
                        onChange={(e) => setPrecio(e.target.value)}
                        required
                    />
                    <label htmlFor="precio" className="form-label">Precio actual de la bebida:</label>
                </div>
                <div className="form-floating mx-5 my-4">
                    <input
                        type="number"
                        className="form-control"
                        id="cantidad"
                        value={cantidad}
                        onChange={(e) => setCantidad(e.target.value)}
                        required
                    />
                    <label htmlFor="cantidad" className="form-label">Cantidad:</label>
                </div>
                <button type="submit" className="mb-4 btn btn-primary">Agregar Bebida</button>
            </form>
        </div>
    );
}