import axios from "axios";

const URL_BASE = "http://localhost:5555";

let allBebidas = [
  { id: 0, nombre: "Coca cola", precio: 1500, cantidad: 5 },
  { id: 1, nombre: "Fernet", precio: 6500, cantidad: 2 },
  { id: 2, nombre: "Fanta", precio: 1400, cantidad: 7 },
  { id: 3, nombre: "Speed", precio: 1000, cantidad: 15 },
];

export function getAllBebidas() {
  const options = {
    method: "GET",
    url: URL_BASE + "/bebidas",
  };

  return axios
    .request(options)
    .then(function (response) {
      //console.log(response.data)
      return response.data;
    })
    .catch(function (error) {
      throw error;
    });
}

export function getBebida(bebidaID) {
  const options = {
    method: "GET",
    url: URL_BASE + `/bebidas/${bebidaID}`,
  };

  return axios
    .request(options)
    .then(function (response) {
      console.log(response.data);
      return(response.data);
    })
    .catch(function (error) {
      throw error;
    });
}

export function addBebida(nuevaBebida) {
  //allBebidas.push(nuevaBebida);
  const options = {
    method: 'POST',
    url: URL_BASE + "/bebidas",
    data: {nombre: nuevaBebida.nombre, precio: nuevaBebida.precio, cantidad: nuevaBebida.cantidad}
  };
  
  return axios.request(options).then(function (response) {
    console.log(response.data);
    return(response.data);
  }).catch(function (error) {
    throw error;
  });
}

export function deleteBebida(bebidaID) {
  const options = {
    method: "DELETE",
    url: URL_BASE + `/bebidas/${bebidaID}`,
  };

  return axios
    .request(options)
    .then(function (response) {
      console.log(response.data);
      return(response.data);
    })
    .catch(function (error) {
      throw error;
    });
}

export function ingresoBebida(bebidaID, cantidad) {
  const options = {
    method: 'PUT',
    url: URL_BASE + `/bebidas/agregar_cantidad/${bebidaID}`,
    params: {cantidad_agregada: cantidad},
  };
  
  return axios.request(options).then(function (response) {
    console.log(response.data);
    return response.data
  }).catch(function (error) {
    console.error('Error agregando bebida:', error);
    throw error;
  });
}

export function retiroBebida(bebidaID, cantidad) {
  const options = {
    method: 'PUT',
    url: URL_BASE + `/bebidas/retirar_cantidad/${bebidaID}`,
    params: {cantidad_retirada: cantidad},
  };
  
  return axios.request(options).then(function (response) {
    console.log(response.data);
    return response.data
  }).catch(function (error) {
    console.error('Error retirando bebida:', error);
    throw error;
  });
}

export function saleBebida(bebidaID, cantidad) {
  const bebida = allBebidas.find((bebida) => bebidaID === bebida.id);
  if (bebida && bebida.cantidad >= cantidad) {
    bebida.cantidad -= cantidad;
  } else
    throw new Error(
      "Cantidad solicitada mayor a la que se encuentra en el deposito"
    );
}

export function cambioPrecioBebida(bebidaID, nuevoPrecio) {
  const options = {
    method: 'PUT',
    url: URL_BASE + `/bebidas/precio/${bebidaID}`,
    params: {nuevo_precio: nuevoPrecio},
  };
  
  return axios.request(options).then(function (response) {
    console.log(response.data);
    return response.data
  }).catch(function (error) {
    console.error('Error cambiando el precio de la bebida: ', error);
    throw error;
  });
}
