import { useState } from "react"
import { useNavigate } from "react-router-dom";
import { addEvento } from "./eventos-service";
import Swal from 'sweetalert2'

export default function AddEvento() {
    const [lugar, setLugar] = useState('');
    const [fecha, setFecha] = useState('');
    const [empleados, setEmpleados] = useState('');
    const [horas, setHoras] = useState('');
    const [paga, setPaga] = useState('');

    const navigate = useNavigate();

    const handleSubmit = (e) => {
        e.preventDefault();

        if (!lugar || !fecha || !empleados || !horas || !paga) {
            Swal.fire({
                icon: 'error',
                title: "Completar todos los campos"
            })
            return;
        }

        let empleadosNuevo = parseInt(empleados);
        let horasNuevo = parseFloat(horas);
        let pagaNuevo = parseInt(paga);

        if (empleados < 0 || horas < 0 || paga < 0 ||
            isNaN(empleadosNuevo) || isNaN(horasNuevo) || isNaN(pagaNuevo)) {
            Swal.fire({
                icon: 'error',
                title: "Coloque numeros validos en los campos numericos"
            })
            return;
        }

        const [anio, mes, dia] = fecha.split('-').map(Number)
        let fechaNuevo = new Date(anio, mes - 1, dia);

        let hoy = new Date();
        hoy.setHours(0, 0, 0, 0);

        if (fechaNuevo < hoy) {
            Swal.fire({
                icon: 'error',
                title: 'La fecha ingresada ya pasó'
            })
            return;
        }

        fechaNuevo = fechaNuevo.toISOString().split('T')[0];

        let eventoNuevo = { lugar: lugar, fecha: fechaNuevo, empleados: empleadosNuevo, horas: horasNuevo, paga_empleados: pagaNuevo };
        addEvento(eventoNuevo)
            .then(response => navigate(`/eventos/info/${response.id}`))
            .catch(error => Swal.fire({
                icon: 'error',
                title: error.message
            }));

    }

    return (
        <div className="container text-center border border-5 rounded-5 mt-3">
            <h1 className="my-3 text-center">Nuevo Evento</h1>
            <div>
                <form onSubmit={handleSubmit}>
                    <div className="form-floating mx-5 my-4">
                        <input
                            type="text"
                            className="form-control"
                            id="lugar"
                            value={lugar}
                            onChange={(e) => setLugar(e.target.value)}
                            required
                        />
                        <label htmlFor="lugar" className="form-label">Lugar del evento:</label>
                    </div>
                    <div className="form-floating mx-5 my-4">
                        <input
                            type="date"
                            className="form-control"
                            id="fecha"
                            value={fecha}
                            onChange={(e) => setFecha(e.target.value)}
                            required
                        />
                        <label htmlFor="fecha" className="form-label">Fecha del evento:</label>
                    </div>
                    <div className="form-floating mx-5 my-4">
                        <input
                            type="number"
                            className="form-control"
                            id="empleados"
                            value={empleados}
                            onChange={(e) => setEmpleados(e.target.value)}
                            required
                        />
                        <label htmlFor="empleados" className="form-label">Numero de empleados:</label>
                    </div>
                    <div className="form-floating mx-5 my-4">
                        <input
                            type="number"
                            className="form-control"
                            id="horas"
                            value={horas}
                            onChange={(e) => setHoras(e.target.value)}
                            required
                        />
                        <label htmlFor="horas" className="form-label">Numero de horas:</label>
                    </div>
                    <div className="form-floating mx-5 my-4">
                        <input
                            type="number"
                            className="form-control"
                            id="paga"
                            value={paga}
                            onChange={(e) => setPaga(e.target.value)}
                            required
                        />
                        <label htmlFor="paga" className="form-label">Paga de empleados:</label>
                    </div>
                    <button type="submit" className="mb-4 btn btn-primary">Agregar Evento</button>
                </form>
            </div>
        </div>
    )
}