import { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import { agregarBebidaEvento, endEvento, getBebidasEvento, getEvento, vuelveBebida } from "./eventos-service";
import { getAllBebidas } from "../deposito/bebidas-service";
import Swal from 'sweetalert2'



export default function InfoEvento() {
    const { eventoID } = useParams();
    const [evento, setEvento] = useState('');
    const [error, setError] = useState('');
    const [bebidasEvento, setBebidasEvento] = useState([]);
    const [bebidasDisponibles, setBebidasDisponibles] = useState([]);
    const [nuevaBebidaID, setNuevaBebidaID] = useState('');

    //const navigate = useNavigate();
    const yesterday = new Date();
    yesterday.setDate(yesterday.getDate() - 1);
    const yesterdayTime = yesterday.getTime();

    useEffect(() => {
        const CargarInfoBebidas = async () => {
            try {
                const eventoData = await getEvento(eventoID);
                setEvento(eventoData);

                const allBebidas = await getAllBebidas();
                const allBebidasDisp = allBebidas.bebidas.filter(bebida => bebida.cantidad > 0);
                setBebidasDisponibles(allBebidasDisp);

                const B_evento = await getBebidasEvento(eventoID);
                if (B_evento.bebidasXevento) {
                    setBebidasEvento(B_evento.bebidasXevento);
                }
                else {
                    setError('error al cargar las bebidas del evento');
                    return;
                }
            } catch (error) {
                setError(error.message);
            }
        }

        CargarInfoBebidas();
    }, [eventoID])

    async function DevolverDeposito(bebidaID) {
        const { value: cantidadDevuelta } = await Swal.fire({
            title: 'Introduce la cantidad que va a regresar:',
            input: 'text',
            showCancelButton: true,
        });
        if (cantidadDevuelta) {
            const cantidadDevueltaNum = parseInt(cantidadDevuelta)
            if (cantidadDevueltaNum <= 0 || isNaN(cantidadDevueltaNum)) {
                Swal.fire({
                    icon: 'error',
                    text: 'Cantidad devuelta no valida'
                })
                return;
            }

            try {
                await vuelveBebida(eventoID, bebidaID, cantidadDevuelta);
                window.location.reload()
            } catch (error) {
                Swal.fire({
                    icon: 'error',
                    text: `Error al devolver la bebida al deposito:  ${error.response.data.detail}`
                })
            }

        }
    }

    const handleAgregarBebida = async () => {
        const { value: cantidadAgregada } = await Swal.fire({
            title: 'Ingresa la cantidad',
            input: 'text',
            showCancelButton: true,
        });
        if (cantidadAgregada) {
            const cantidadAgregadaNum = parseInt(cantidadAgregada)
            if (isNaN(cantidadAgregadaNum) || cantidadAgregadaNum < 0) {
                Swal.fire({
                    icon: 'error',
                    text: 'Cantidad devuelta no valida'
                })
                return;
            }
            try {
                await agregarBebidaEvento(eventoID, nuevaBebidaID, cantidadAgregadaNum);
                window.location.reload();
            } catch (error) {
                Swal.fire({
                    icon: 'error',
                    text: `Error al devolver la bebida al deposito:  ${error.response.data.detail}`
                })
            }
        }
    }

    async function TerminarEvento() {
        const infoEventoTerminado = await endEvento(eventoID);
        Swal.fire({
            title: 'Informacion del evento finalizado',
            icon: 'info',
            html: `Ingresos totales por venta de bebidas: $${infoEventoTerminado.ingresos_totales}<br>
                    Paga a empleados: $${infoEventoTerminado.paga_empleados}<br>
                    Ingresos brutos: $${infoEventoTerminado.ingresos_bruto}`
        })
        //navigate('/eventos')
    }

    return (
        <div className="container text-center border border-5 rounded-5 mt-3">
            {error ? <h1 className="text-danger">{error}</h1> : null}
            <h1 className="mt-3 mb-3 text-center">Info de Evento</h1>
            <div className="table-responsive">
                <table className="table table-dark table-striped">
                    <thead className="" style={{ position: 'sticky', top: 0, backgroundColor: 'whitesmoke' }}>
                        <tr className="text-center fs-4 fst-italic text-decoration-underline">
                            <th>Lugar</th>
                            <th>Fecha</th>
                            <th>Empleados</th>
                            <th>Horas</th>
                            <th>Paga empleado</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td className="text-center">{evento.lugar}</td>
                            {Date.now() < new Date(evento.fecha).getTime() ? <td className="text-center">{evento.fecha}</td> : <td className="text-center text-danger">{evento.fecha}</td>}
                            <td className="text-center">{evento.empleados}</td>
                            <td className="text-center">{evento.horas}</td>
                            <td className="text-center">{evento.paga_empleados}</td>
                        </tr>
                    </tbody>
                </table>
            </div>
            <h1 className="mt-3 mb-3 text-center">Lista de bebidas</h1>

            {yesterdayTime < new Date(evento.fecha).getTime() ?
                <div className="my-3 mx-5">
                    <label htmlFor="nuevoAlumno">Agregar bebida:</label>
                    <select
                        id="nuevoAlumno"
                        className="form-select"
                        value={nuevaBebidaID}
                        onChange={(e) => setNuevaBebidaID(e.target.value)}
                    >
                        <option value="" disabled>
                            Seleccione una bebida
                        </option>
                        {bebidasDisponibles.sort((function (a, b) {
                            if (a.nombre > b.nombre) return 1;
                            if (a.nombre < b.nombre) return -1;
                            return 0
                        })).map((bebida) => {
                            if (bebida.cantidad > 0)
                                return (
                                    <option key={bebida.id} value={bebida.id}>
                                        {bebida.nombre.toUpperCase()},&nbsp;&nbsp;disponibles: {bebida.cantidad}
                                    </option>
                                )
                        })}
                    </select>
                    <button className="btn btn-primary mt-2" onClick={handleAgregarBebida}>
                        Agregar Bebida
                    </button>
                </div>
                : ''}

            <div className="table-responsive overflow-auto" style={{ maxHeight: '300px' }}>
                <table className="table table-dark table-striped">
                    <thead className="" style={{ position: 'sticky', top: 0, backgroundColor: 'whitesmoke' }}>
                        <tr className="text-center fs-4 fst-italic text-decoration-underline">
                            <th>Producto</th>
                            <th>Cantidad</th>
                            <th></th>
                        </tr>
                    </thead>
                    <tbody>
                        {bebidasEvento.map((bebida) => (
                            <tr key={bebida.idBebida}>
                                <td className="text-center">{bebida.nombreBebida}</td>
                                <td className="text-center">{bebida.cantidad}</td>
                                <td>
                                    <button className="btn btn-info" onClick={() => DevolverDeposito(bebida.idBebida)}>Devolver a deposito</button>
                                </td>
                            </tr>
                        ))}

                    </tbody>
                </table>
            </div>
            <div>
                <button className="btn btn-success mb-3" onClick={() => TerminarEvento()}>Informacion de fin de evento</button>
            </div>
        </div>
    );
}